AppStateXController class State Object Controller

A Controller for the 'app level'.

dartdoc:

Inheritance
Implemented types

Constructors

AppStateXController([StateX<StatefulWidget>? state])
Optionally supply a 'State' object to be linked to this State Controller.

Properties

appState → AppStateX<StatefulWidget>?
Returns the 'first' StateX object in the App Supply this version of AppStateX
no setterinherited
dataObject ↔ Object?
This is of type Object allowing you to propagate any class object you wish down the widget tree.
getter/setter pairinherited
didCallChangeEvent → bool
The 'Change' event has already been called in a previous State object
no setterinherited
firstState → StateX<StatefulWidget>?
Return the first State object
no setterinherited
hasChangeListeners → bool
Whether any listeners are currently registered.
no setterinherited
hasChangeNotifierImpl → bool
A flag. Instantiated Change Notifier
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
identifier → String
A unique key is assigned to all State Controllers, State objects Used in large projects to separate objects into teams.
no setterinherited
inDebugMode → bool
Determines if running in an IDE or in production. Returns true if the App is under in the Debugger and not production.
no setterinherited
lastContext → BuildContext?
Returns the 'latest' context in the App.
no setterinherited
lastState → StateX<StatefulWidget>?
Return the 'latest' State object
no setterinherited
rootState → AppStateX<StatefulWidget>?
Returns the 'first' StateX object in the App
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setBuilderUsed → bool
A flag. Noting if the function above is ever used.
no setterinherited
state → StateX<StatefulWidget>?
Supply this version of StateX
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
addListener(VoidCallback listener) → bool
Register a closure to be called when the object changes.
inherited
addState(StateX<StatefulWidget>? state) → String
Associate this StateXController to the specified State object to use that State object's functions and features. Returns that State object's unique identifier.
inherited
deactivate() → void
The framework calls this method whenever it removes this StateX object from the tree.
inherited
dependOnInheritedWidget(BuildContext? context) → bool
Link a widget to an InheritedWidget
inherited
detachedAppLifecycleState() → void
Either be in the progress of attaching when the engine is first initializing or after the view being destroyed due to a Navigator pop.
inherited
didChangeAccessibilityFeatures() → void
Either be in the progress of attaching when the engine is first initializing or after the view being destroyed due to a Navigator pop.
inherited
didChangeAppLifecycleState(AppLifecycleState state) → void
Called when the system puts the app in the background or returns the app to the foreground.
inherited
didChangeDependencies() → void
Called when immediately after initState. Otherwise called only if a dependency of an InheritedWidget.
inherited
didChangeLocales(List<Locale>? locales) → void
Called when the system tells the app that the user's locale has changed.
inherited
didChangeMetrics() → void
Called when the application's UI dimensions change. For example, when a phone is rotated.
inherited
didChangePlatformBrightness() → void
Brightness changed.
inherited
didChangeTextScaleFactor() → void
Called when the platform's text scale factor changes.
inherited
didHaveMemoryPressure() → void
Called when the system is running low on memory.
inherited
didPop() → void
Called when this State is popped off a route.
inherited
didPopNext() → void
The top route has been popped off, and this route shows up.
inherited
didPopRoute() → Future<bool>
Called when the system tells the app to pop the current route. For example, on Android, this is called when the user presses the back button.
inherited
didPush() → void
Called when this State is first added to as a Route observer?!
inherited
didPushNext() → void
New route has been pushed, and this State object's route is no longer current.
inherited
didPushRoute(String route) → Future<bool>
Called when the host tells the app to push a new route onto the navigator.
inherited
didPushRouteInformation(RouteInformation routeInformation) → Future<bool>
Called when the host tells the application to push a new RouteInformation and a restoration state onto the router.
inherited
didRequestAppExit() → Future<AppExitResponse>
Called when a request is received from the system to exit the application. Exiting the application can proceed with AppExitResponse.exit; Cancel and do not exit the application with AppExitResponse.cancel;
inherited
didUpdateWidget(covariant StatefulWidget oldWidget) → void
Override this method to respond to when the StatefulWidget is recreated.
inherited
dispose() → void
Part of the Flutter engine's 'garbage collection' process. Note: YOU WILL HAVE NO IDEA WHEN THIS WILL RUN in the Framework. BEST NOT TO USE THIS FUNCTION EVER!
inherited
disposeChangeNotifier() → void
Don't forget to call this method in the appropriate dispose() function!
inherited
forEachState(void func(StateX<StatefulWidget> state), {bool? reversed}) → bool
To externally 'process' through the State objects. Invokes func on each StateX possessed by this object.
inherited
hiddenAppLifecycleState() → void
All views of an application are hidden, either because the application is about to be paused (on iOS and Android), or because it has been minimized or placed on a desktop that is no longer visible (on non-web desktop), or is running in a window or tab that is no longer visible (on the web).
inherited
inactiveAppLifecycleState() → void
The application is in an inactive state and is not receiving user input.
inherited
initAsync() → Future<bool>
Initialize any 'time-consuming' operations at the beginning. Implement any asynchronous operations needed done at start up.
inherited
initChangeNotifier() → void
inherited
initState() → void
The framework will call this method exactly once. Only when the StateX object is first created.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyClients() → bool
In harmony with Flutter's own API Rebuild the InheritedWidget of the 'closes' InheritedStateX object if any.
inherited
notifyListeners() → bool
Call all the registered listeners.
inherited
ofState<T extends StateX<StatefulWidget>>() → T?
Retrieve the StateX object of type T Returns null if not found
inherited
onAsyncError(FlutterErrorDetails details) → void
initAsync() has failed and a 'error' widget instead will be displayed. This takes in the snapshot.error details.
inherited
onConnectivityChanged(ConnectivityResult result) → void
If the device's connectivity changes.
override
pausedAppLifecycleState() → void
The application is not currently visible to the user, not responding to user input, and running in the background.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
removeListener(VoidCallback listener) → bool
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
resumedAppLifecycleState() → void
The application is visible and responding to user input.
inherited
setBuilder(MaybeBuildWidgetType? builder) → Widget
Returns a widget from builder assuming the current object is a Listenable const SizedBox.shrink() otherwise
inherited
setRootStateX(StateX<StatefulWidget>? state) → bool
Important to record the 'root' StateX object. Its an InheritedWidget!
inherited
setState(VoidCallback fn) → void
Call a State object's setState() and notify any listeners
inherited
stateOf<T extends StatefulWidget>() → StateX<StatefulWidget>?
Supply this version of StateX
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited