HandleError mixin

Copyright 2020 Andrious Solutions Ltd. All rights reserved. Use of this source code is governed by a 2-clause BSD License. The main directory contains that LICENSE file.

     Created  09 Apr 2020
Mixin applications

Properties

errorMsg → String
Simply display the error.
no setter
hasError → bool
Indicate if the app is 'in error.'
no setter
hashCode → int
The hash code for this object.
no setterinherited
inError → bool
Indicate if app is 'in error.'
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getError([dynamic error]) → Exception?
Return the 'last' error if any.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited