Assets class

The Assets manager for this custom framework.

Constructors

Assets()
Singleton pattern
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Clean up after the Assets Manager
getBoolData(String key, Future<bool> parser(String value)) → Future<bool>
Retrieve a boolean value by its Key value. Supply a parser function to process the operation. (See. Flutter's AssetBundle.loadStructuredData
getData<T>(String key, Future<T> parser(String value)) → Future<T?>
Retrieve an object of type, T, by its String value. Supply a parser function to process the operation. (See. Flutter's AssetBundle.loadStructuredData
getImage(String key, {AssetBundle? bundle, String? package}) → AssetImage
Retrieve an AssetImage by its Key value. Supply a parser function to process the operation. (See. Flutter's AssetBundle.loadStructuredData
getStringData(String key, Future<String> parser(String value)) → Future<String?>
Retrieve a String by its Key value. Supply a parser function to process the operation. (See. Flutter's AssetBundle.loadStructuredData
init(BuildContext context, {String? dir}) → Future<bool>
Initialize the App's Assets Manager.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getStreamF(String key) → Future<ByteData>
Retrieve a 'ByteData' object by its Key value.
getStringF(String key, {bool cache = true}) → Future<String>
Retrieve a String value by its Key value.
setPath(String key) → String?
Determine the appropriate path for the asset.