Adaptive class

Constructors

Adaptive()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

cm(num centimeters) → double
The respective value in centimeters
dp(num densityPixel) → double
Calculates the material dp (Pixel Density) (https://material.io/design/layout/pixel-density.html#pixel-density-on-android))
h(num height) → double
Calculates the height depending on the device's screen size
inches(num inches) → double
The respective value in inches
mm(num millimeters) → double
The respective value in millimeters
pc(num picas) → double
The respective value in picas (1/6th of 1 inch)
pt(num point) → double
The respective value in points (1/72th of 1 inch)
px(num pixels) → double
The respective value in pixels (default)
Q(num quarterMillimeters) → double
The respective value in quarter-millimeters
sh(num height) → double
Calculates the height depending on the device's screen size
sp(num scalablePixel) → double
Calculates the sp (Scalable Pixel) depending on the device's pixel density and aspect ratio
sw(num width) → double
Calculates the width depending on the device's screen size
w(num width) → double
Calculates the width depending on the device's screen size