CustomTransitionPage<T> class

Page with custom transition functionality.

To be used instead of MaterialPage or CupertinoPage, which provide their own transitions.

Inheritance

Constructors

CustomTransitionPage({required Widget child, required Widget transitionsBuilder(BuildContext context, Animation<double> animation, Animation<double> secondaryAnimation, Widget child), Duration transitionDuration = const Duration(milliseconds: 300), Duration reverseTransitionDuration = const Duration(milliseconds: 300), bool maintainState = true, bool fullscreenDialog = false, bool opaque = true, bool barrierDismissible = false, Color? barrierColor, String? barrierLabel, LocalKey? key, String? name, Object? arguments, String? restorationId})
Constructor for a page with custom transition functionality.
const

Properties

arguments → Object?
The arguments passed to this route.
finalinherited
barrierColor → Color?
The color to use for the modal barrier.
final
barrierDismissible → bool
Whether you can dismiss this route by tapping the modal barrier.
final
barrierLabel → String?
The semantic label used for a dismissible barrier.
final
canPop → bool
When false, blocks the associated route from being popped.
finalinherited
child → Widget
The content to be shown in the Route created by this page.
final
fullscreenDialog → bool
Whether this page route is a full-screen dialog.
final
hashCode → int
The hash code for this object.
no setterinherited
key → LocalKey?
The key associated with this page.
finalinherited
maintainState → bool
Whether the route should remain in memory when it is inactive.
final
name → String?
The name of the route (e.g., "/settings").
finalinherited
onPopInvoked → PopInvokedWithResultCallback<T>
Called after a pop on the associated route was handled.
finalinherited
opaque → bool
Whether the route obscures previous routes when the transition is complete.
final
restorationId → String?
Restoration ID to save and restore the state of the Route configured by this page.
finalinherited
reverseTransitionDuration → Duration
A duration argument to customize the duration of the custom page transition on pop.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transitionDuration → Duration
A duration argument to customize the duration of the custom page transition.
final
transitionsBuilder → Widget Function(BuildContext context, Animation<double> animation, Animation<double> secondaryAnimation, Widget child)
Override this method to wrap the child with one or more transition widgets that define how the route arrives on and leaves the screen.
final

Methods

canUpdate(Page other) → bool
Whether this page can be updated with the other page.
inherited
createRoute(BuildContext context) → Route<T>
Creates the Route that corresponds to this page.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited