Device class

Constructors

Device()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

aspectRatio ↔ double
Device's Aspect Ratio
getter/setter pair
boxConstraints ↔ BoxConstraints
Device's BoxConstraints
getter/setter pair
deviceType ↔ DeviceType
Type of Device
getter/setter pair
height ↔ double
Device's Height
getter/setter pair
orientation ↔ Orientation
Device's Orientation
getter/setter pair
pixelRatio ↔ double
Device's Pixel Ratio
getter/setter pair
safeHeight ↔ double
Device's Remaining Height after applying SafeArea
getter/setter pair
safeWidth ↔ double
Device's Remaining Width after applying SafeArea
getter/setter pair
screenType ↔ ScreenType
Type of Screen
getter/setter pair
width ↔ double
Device's Width
getter/setter pair

Static Methods

setScreenSize(BuildContext context, BoxConstraints constraints, Orientation currentOrientation, double maxMobileWidth, [double? maxTabletWidth]) → void
Sets the Screen's size and Device's Orientation, BoxConstraints, Height, and Width