FutureBuilderStateMixin mixin StateX class Using FutureBuilder

Supply a FutureBuilder to a State object.

dartdoc:

Superclass constraints

Properties

buildOverridden → bool
A flag noting if the build() function was overridden or not.
no setter
caughtAsyncError → bool
A flag noting an Async error was caught or not
no setter
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshot → AsyncSnapshot<bool>?
Supply the AsyncSnapshot
no setter
usingCupertino → bool
Is the CupertinoApp being used?
no setter
widget → StatefulWidget
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
buildF(BuildContext context) → Widget
Implement this function instead of the build() function to utilize a built-in FutureBuilder Widget.
catchAsyncError(Object error) → Future<bool>
Catch it if the initAsync() throws an error WITH GREAT POWER COMES GREAT RESPONSIBILITY Return true to ignore the error, false to continue the error handling
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant StatefulWidget oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Clean up
override
initAsync() → Future<bool>
You're to override this function and initialize any asynchronous operations
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAsyncError(FlutterErrorDetails details) → void
initAsync() has failed and a 'error' widget instead will be displayed. This takes in the snapshot.error details.
onSplashScreen(BuildContext context) → Widget?
Supply a 'splash screen' while the FutureBuilder is processing.
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
runInitAsync() → bool
Call initAsync() all the time if return true. Conditional calls initAsync() creating a Future with every rebuild
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited