GoException class

Thrown when GoRouter can not handle a user request.

Implemented types

Constructors

GoException(String message)
Creates an exception with message describing the reason.

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
The reason that causes this exception.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited