GoRouteInformationParser class

Converts between incoming URLs and a RouteMatchList using RouteMatcher. Also performs redirection using RouteRedirector.

Inheritance

Constructors

GoRouteInformationParser({required RouteConfiguration configuration, required ParserExceptionHandler? onParserException})
Creates a GoRouteInformationParser.

Properties

configuration → RouteConfiguration
The route configuration used for parsing RouteInformations.
final
debugParserFuture ↔ Future<RouteMatchList>?
The future of current route parsing.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
onParserException → ParserExceptionHandler?
The exception handler that is called when parser can't handle the incoming uri.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseRouteInformation(RouteInformation routeInformation) → Future<RouteMatchList>
Converts the given route information into parsed data to pass to a RouterDelegate.
override
parseRouteInformationWithDependencies(RouteInformation routeInformation, BuildContext context) → Future<RouteMatchList>
Called by the Router. The
override
restoreRouteInformation(RouteMatchList configuration) → RouteInformation?
for use by the Router architecture as part of the RouteInformationParser
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited