GoRouterDelegate class

GoRouter implementation of RouterDelegate.

Inheritance
Mixed-in types

Constructors

GoRouterDelegate({required RouteConfiguration configuration, required GoRouterBuilderWithNav builderWithNav, required GoRouterPageBuilder? errorPageBuilder, required GoRouterWidgetBuilder? errorBuilder, required List<NavigatorObserver> observers, required bool routerNeglect, String? restorationScopeId, bool requestFocus = true})
Constructor for GoRouter's implementation of the RouterDelegate base class.

Properties

builder ↔ RouteBuilder
Builds the top-level Navigator given a configuration and location.
latefinal
currentConfiguration ↔ RouteMatchList
For use by the Router architecture as part of the RouterDelegate.
getter/setter pairoverride-getter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
For use by the Router architecture as part of the RouterDelegate.
no setter
routerNeglect → bool
Set to true to disable creating history entries on the web.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → GoRouterState
The top GoRouterState, the state of the route that was last used in either GoRouter.go or GoRouter.push.
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
build(BuildContext context) → Widget
For use by the Router architecture as part of the RouterDelegate.
override
canPop() → bool
Returns true if the active Navigator can pop.
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pop<T extends Object?>([T? result]) → void
Pops the top-most route.
popRoute() → Future<bool>
Called by the Router when the Router.backButtonDispatcher reports that the operating system is requesting that the current route be popped.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setInitialRoutePath(RouteMatchList configuration) → Future<void>
Called by the Router at startup with the structure that the RouteInformationParser obtained from parsing the initial route.
inherited
setNewRoutePath(RouteMatchList configuration) → Future<void>
For use by the Router architecture as part of the RouterDelegate.
override
setRestoredRoutePath(RouteMatchList configuration) → Future<void>
Called by the Router during state restoration.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited