ImperativeRouteMatch class

The route match that represent route pushed through GoRouter.push.

Inheritance

Constructors

ImperativeRouteMatch({required ValueKey<String> pageKey, required RouteMatchList matches, required Completer<Object?> completer})
Constructor for ImperativeRouteMatch.

Properties

completer → Completer<Object?>
The completer for the future returned by GoRouter.push.
final
hashCode → int
The hash code for this object.
no setteroverride
matchedLocation → String
The location string that matches the route.
finalinherited
matches → RouteMatchList
The matches that produces this route match.
final
pageKey → ValueKey<String>
The page key.
finalinherited
route → GoRoute
The matched route.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildState(RouteConfiguration configuration, RouteMatchList matches) → GoRouterState
Gets the state that represent this route match.
override
complete([dynamic value]) → void
Called when the corresponding Route associated with this route match is completed.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override