InheritedWidgetStateMixin mixin StateX class Using InheritedWidget

Supplies an InheritedWidget to a State class

dartdoc:

Superclass constraints

Properties

builderOverridden → bool
A flag. Note if builder() function was overridden or not.
no setter
buildFOverridden → bool
A flag. Note if buildF() function was overridden or not.
no setter
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useInherited → bool
A flag determining whether the built-in InheritedWidget is used or not.
no setter
widget → StatefulWidget
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
builder(BuildContext context) → Widget StateX class
Use this function instead of the build() function
buildF(BuildContext context) → Widget StateX class
dartdoc:
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
dependOnInheritedWidget(BuildContext? context) → bool
Set the specified widget (through its context) as a dependent of the InheritedWidget
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant StatefulWidget oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Copy particular properties from the 'previous' StateX
override
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyClients() → bool
In harmony with Flutter's own API there's also a notifyClients() function Rebuild the InheritedWidget of the 'closes' InheritedStateX object if any.
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setBuilder(WidgetBuilder? builder) → Widget
Called when the State's InheritedWidget is called again This 'widget function' will be called again.
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
stateSet(WidgetBuilder? builder) → Widget
Called when the State's InheritedWidget is called again This 'widget builder' will be called again.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
updateShouldNotify(covariant InheritedWidget oldWidget) → bool
Determine if the dependencies should be updated.

Operators

operator ==(Object other) → bool
The equality operator.
inherited