RootStateMixin mixin StateX class State Object Controller

Supply access to the 'Root' State object.

dartdoc:

Properties

dataObject ↔ Object?
This is of type Object allowing you to propagate any class object you wish down the widget tree.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inDebugMode → bool
Determines if running in an IDE or in production. Returns true if the App is under in the Debugger and not production.
no setter
lastContext → BuildContext?
Returns the 'latest' context in the App.
no setter
rootState → AppStateX<StatefulWidget>?
Returns the 'first' StateX object in the App
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setRootStateX(StateX<StatefulWidget>? state) → bool
Important to record the 'root' StateX object. Its an InheritedWidget!
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited