RouteBuilder class

Builds the top-level Navigator for GoRouter.

Constructors

RouteBuilder({required RouteConfiguration configuration, required GoRouterBuilderWithNav builderWithNav, required GoRouterPageBuilder? errorPageBuilder, required GoRouterWidgetBuilder? errorBuilder, required String? restorationScopeId, required List<NavigatorObserver> observers, required PopPageWithRouteMatchCallback onPopPageWithRouteMatch, bool requestFocus = true})
RouteBuilder constructor.

Properties

builderWithNav → GoRouterBuilderWithNav
Builder function for a go router with Navigator.
final
configuration → RouteConfiguration
The route configuration for the app.
final
errorBuilder → GoRouterWidgetBuilder?
Error widget builder for the go router delegate.
final
errorPageBuilder → GoRouterPageBuilder?
Error page builder for the go router delegate.
final
hashCode → int
The hash code for this object.
no setterinherited
observers → List<NavigatorObserver>
NavigatorObserver used to receive notifications when navigating in between routes. changes.
final
onPopPageWithRouteMatch → PopPageWithRouteMatchCallback
A callback called when a route produced by match is about to be popped with the result.
final
requestFocus → bool
Whether or not the navigator created by this builder and it's new topmost route should request focus when the new route is pushed onto the navigator.
final
restorationScopeId → String?
Restoration ID to save and restore the state of the navigator, including its history.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, RouteMatchList matchList, bool routerNeglect) → Widget
Builds the top-level Navigator for the given RouteMatchList.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited