RouteInformationState<T> class

The data class to be stored in RouteInformation.state to be used by GoRouteInformationParser.

This state class is used internally in go_router and will not be sent to the engine.

Constructors

RouteInformationState({Object? extra, Completer<T?>? completer, RouteMatchList? baseRouteMatchList, required NavigatingType type})
Creates an InternalRouteInformationState.

Properties

baseRouteMatchList → RouteMatchList?
The base route match list to push on top to.
final
completer → Completer<T?>?
The completer that needs to be completed when the newly added route is popped off the screen.
final
extra → Object?
The extra object used when navigating with GoRouter.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → NavigatingType
The type of navigation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited