RouteMatchBase class abstract

The base class for various route matches.

Mixed-in types

Constructors

RouteMatchBase()
An abstract route match base
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
matchedLocation → String
The location string that matches the route.
no setter
pageKey → ValueKey<String>
The page key.
no setter
route → RouteBase
The matched route.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildState(RouteConfiguration configuration, RouteMatchList matches) → GoRouterState
Gets the state that represent this route match.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

match({required RouteBase route, required Map<String, String> pathParameters, required GlobalKey<NavigatorState> rootNavigatorKey, required Uri uri}) → List<RouteMatchBase>
Generates a list of RouteMatchBase objects by matching the route and its sub-routes with uri.