RoutingConfig class Configuration

A set of parameters that defines routing in GoRouter.

This is typically used with GoRouter.routingConfig to create a go router with dynamic routing config.

See routing_config.dart.

Constructors

RoutingConfig({required List<RouteBase> routes, GoRouterRedirect redirect = _defaultRedirect, int redirectLimit = 5})
Creates a routing config.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
redirect → GoRouterRedirect
The top-level callback allows the app to redirect to a new location.
final
redirectLimit → int
The maximum number of redirection allowed.
final
routes → List<RouteBase>
The supported routes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited