ShellRouteBase class abstract

Base class for classes that act as shells for sub-routes, such as ShellRoute and StatefulShellRoute.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
parentNavigatorKey → GlobalKey<NavigatorState>?
An optional key specifying which Navigator to display this route's screen onto.
finalinherited
redirect → GoRouterRedirect?
An optional redirect function for this route.
finalinherited
routes → List<RouteBase>
The list of child routes associated with this route.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildPage(BuildContext context, GoRouterState state, ShellRouteContext shellRouteContext) → Page?
Attempts to build the Page representing this shell route.
buildWidget(BuildContext context, GoRouterState state, ShellRouteContext shellRouteContext) → Widget?
Attempts to build the Widget representing this shell route.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
Returns the key for the Navigator that is to be used for the specified immediate sub-route of this shell route.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited