SizerExt extension

on

Properties

cm → double

Available on num, provided by the SizerExt extension

The respective value in centimeters
no setter
dp → double

Available on num, provided by the SizerExt extension

Calculates the material dp (Pixel Density) (https://material.io/design/layout/pixel-density.html#pixel-density-on-android))
no setter
h → double

Available on num, provided by the SizerExt extension

Calculates the height depending on the device's screen size
no setter
inches → double

Available on num, provided by the SizerExt extension

The respective value in inches
no setter
mm → double

Available on num, provided by the SizerExt extension

The respective value millimeters
no setter
pc → double

Available on num, provided by the SizerExt extension

The respective value in picas (1/6th of 1 inch)
no setter
pt → double

Available on num, provided by the SizerExt extension

The respective value in points (1/72th of 1 inch)
no setter
px → double

Available on num, provided by the SizerExt extension

The respective value in pixels (default)
no setter
Q → double

Available on num, provided by the SizerExt extension

The respective value in quarter-millimeters
no setter
sh → double

Available on num, provided by the SizerExt extension

Calculates the height depending on the remaining device height after using SafeArea Eg: 20.sh -> will take 20% of the safe area height
no setter
sp → double

Available on num, provided by the SizerExt extension

Calculates the sp (Scalable Pixel) depending on the device's pixel density and aspect ratio
no setter
spa → double

Available on num, provided by the SizerExt extension

Calculates the sp (Scalable Pixel) based on Issue #27
no setter
sw → double

Available on num, provided by the SizerExt extension

Calculates the width depending on the remaining device width after using SafeArea
no setter
vmax → double

Available on num, provided by the SizerExt extension

Respective percentage of the viewport's larger dimension.
no setter
vmin → double

Available on num, provided by the SizerExt extension

Respective percentage of the viewport's smaller dimension.
no setter
w → double

Available on num, provided by the SizerExt extension

Calculates the width depending on the device's screen size
no setter