StatefulNavigationShellState class

State for StatefulNavigationShell.

Inheritance
Mixed-in types

Properties

bucket → RestorationBucket?
The RestorationBucket used for the restoration data of the RestorablePropertys registered to this mixin.
no setterinherited
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
currentIndex → int
The index of the currently active StatefulShellBranch.
no setter
hashCode → int
The hash code for this object.
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
restorationId → String?
The restoration ID used for the RestorationBucket in which the mixin will store the restoration data of all registered properties.
no setteroverride
restorePending → bool
Whether restoreState will be called at the beginning of the next build phase.
no setterinherited
route → StatefulShellRoute
The associated StatefulShellRoute.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widget → StatefulNavigationShell
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didToggleBucket(RestorationBucket? oldBucket) → void
Called when bucket switches between null and non-null values.
inherited
didUpdateRestorationId() → void
Must be called when the value returned by restorationId changes.
inherited
didUpdateWidget(covariant StatefulNavigationShell oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
goBranch(int index, {bool initialLocation = false}) → void
Navigate to the last location of the StatefulShellBranch at the provided index in the associated StatefulShellBranch.
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
registerForRestoration(RestorableProperty<Object?> property, String restorationId) → void
Registers a RestorableProperty for state restoration.
inherited
restoreState(RestorationBucket? oldBucket, bool initialRestore) → void
Called to initialize or restore the RestorablePropertys used by the State object.
override
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
unregisterFromRestoration(RestorableProperty<Object?> property) → void
Unregisters a RestorableProperty from state restoration.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited