StatefulShellRouteData class abstract

Base class for supporting StatefulShellRoute

Inheritance

Constructors

StatefulShellRouteData()
Default const constructor
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

builder(BuildContext context, GoRouterState state, StatefulNavigationShell navigationShell) → Widget
builder is used to build the widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pageBuilder(BuildContext context, GoRouterState state, StatefulNavigationShell navigationShell) → Page<void>
pageBuilder is used to build the page
redirect(BuildContext context, GoRouterState state) → FutureOr<String?>
An optional redirect function for this route.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

$route<T extends StatefulShellRouteData>({required T factory(GoRouterState), required List<StatefulShellBranch> branches, GlobalKey<NavigatorState>? parentNavigatorKey, ShellNavigationContainerBuilder? navigatorContainerBuilder, String? restorationScopeId}) → StatefulShellRoute
A helper function used by generated code.