TypedGoRoute<T extends GoRouteData> class

A superclass for each typed go route descendant

Inheritance
Annotations
  • @Target.new(<TargetKind>{TargetKind.library, TargetKind.classType})

Constructors

TypedGoRoute({required String path, String? name, List<TypedRoute<RouteData>> routes = const <TypedRoute<RouteData>>[]})
Default const constructor
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name that corresponds to this route. Used by Analytics services such as Firebase Analytics to log the screen views in their system.
final
path → String
The path that corresponds to this route.
final
routes → List<TypedRoute<RouteData>>
Child route definitions.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited