AppStateExtension extension

on

Properties

context → BuildContext?

Available on AppObject, provided by the AppStateExtension extension

Retrieve the 'latest' context
no setter
inDebugMode → bool

Available on AppObject, provided by the AppStateExtension extension

Determines if running in an IDE or in production.
no setter
useCupertino → bool

Available on AppObject, provided by the AppStateExtension extension

Indicates if the App is running the Cupertino interface theme.
no setter
useMaterial → bool

Available on AppObject, provided by the AppStateExtension extension

Indicates if the App is running the Material interface theme.
no setter

Methods

catchError(Object? ex, {StackTrace? stack, String? library, DiagnosticsNode? context, IterableFilter<String>? stackFilter, InformationCollector? informationCollector, bool? silent}) → void

Available on AppObject, provided by the AppStateExtension extension

Catch and explicitly handle the error.
changeLocale(Locale? locale) → Future<bool>

Available on AppObject, provided by the AppStateExtension extension

Explicitly change the app's locale.
changeUI(String ui) → void

Available on AppObject, provided by the AppStateExtension extension

Explicitly change to a particular interface.
dependOnInheritedWidget(BuildContext? context) → void

Available on AppObject, provided by the AppStateExtension extension

Link a widget to a InheritedWidget in the root State object.
notifyClients() → void

Available on AppObject, provided by the AppStateExtension extension

Rebuild dependencies to the root State object's InheritedWidget
refresh() → void

Available on AppObject, provided by the AppStateExtension extension

Refresh the 'current/latest' State object and 'root/first' State object. todo: Is refresh() deprecated?
setState(VoidCallback fn) → void

Available on AppObject, provided by the AppStateExtension extension

Refresh the root State object with the passed function.