AppDrawer class

A standard Drawer object for your Flutter app.

Inheritance

Constructors

AppDrawer({Key? key, Color? backgroundColor, double? elevation, Color? shadowColor, Color? surfaceTintColor, ShapeBorder? shape, double? width, DrawerHeader? header, List<Widget>? children, String? semanticLabel, Axis? scrollDirection, bool? reverse, ScrollController? scrollController, bool? primary, ScrollPhysics? physics, bool? shrinkWrap, EdgeInsetsGeometry? padding, double? itemExtent, Widget? prototypeItem, bool? addAutomaticKeepAlives, bool? addRepaintBoundaries, bool? addSemanticIndexes})
Supply the properties to a Material Design Drawer Widget.

Properties

addAutomaticKeepAlives → bool?
Whether to wrap each child in an AutomaticKeepAlive.
final
addRepaintBoundaries → bool?
Whether to wrap each child in a RepaintBoundary.
final
addSemanticIndexes → bool?
Whether to wrap each child in an IndexedSemantics.
final
backgroundColor → Color?
The drawer's color.
final
children → List<Widget>?
The List of Widget items that make up the Drawer's contents.
final
elevation → double?
The z-coordinate at which to place this drawer relative to its parent.
final
hashCode → int
The hash code for this object.
no setterinherited
The top-most region of a material design drawer.
final
itemExtent → double?
If non-null, forces the children to have the given extent in the scroll direction.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding → EdgeInsetsGeometry?
The amount of space by which to inset the children.
final
physics → ScrollPhysics?
How the scroll view should respond to user input.
final
primary → bool?
Whether this is the primary scroll view associated with the parent
final
prototypeItem → Widget?
If non-null, forces the children to have the same extent as the given widget in the scroll direction.
final
reverse → bool?
Whether the scroll view scrolls in the reading direction.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollController → ScrollController?
An object that can be used to control the position to which this scroll view is scrolled.
final
scrollDirection → Axis?
The axis along which the scroll view scrolls.
final
semanticLabel → String?
The semantic label of the dialog used by accessibility frameworks.
final
shadowColor → Color?
The color used to paint a drop shadow under the drawer's Material, which reflects the drawer's elevation.
final
shape → ShapeBorder?
The shape of the drawer.
final
shrinkWrap → bool?
Whether the extent of the scroll view in the scrollDirection should be determined by the contents being viewed
final
surfaceTintColor → Color?
The color used as a surface tint overlay on the drawer's background color, which reflects the drawer's elevation.
final
width → double?
The width of the drawer.
final

Methods

add(Widget? item) → void
one item
addAll(List<Widget>? items) → void
Add a List
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(Widget? item) → bool
Remove an item
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited