AppPopupMenuController class

Uses the String type as menu options

Mixed-in types

Constructors

AppPopupMenuController()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCanceled() → void
Called when the user dismisses the popup menu without selecting an item.
inherited
onChild() → Widget?
The widget used for this button
inherited
onClipBehavior() → Clip?
The clip shape of the menu.
inherited
onColor() → Color?
The background color used for the menu
inherited
onConstraints() → BoxConstraints?
Make the menu wider than the default maximum width
inherited
onElevation() → double?
This controls the size of the shadow below the menu.
inherited
onEnabled() → bool?
Whether this popup menu button is interactive
inherited
onEnableFeedback() → bool?
Whether detected gestures should provide acoustic and/or haptic feedback
inherited
onIcon() → Widget?
The icon is used for this button
inherited
onIconSize() → double?
the size of the Icon.
inherited
onInitialValue() → String?
The value of the menu item, if any, that should be highlighted when the menu opens.
inherited
onItemBuilder() → PopupMenuItemBuilder<String>?
Explicitly pass a BuildContext: List<PopupMenuEntry<T>> Function(BuildContext context);
inherited
onItems() → List<String>?
List of menu items to appear in the popup menu.
inherited
onMenuEntries() → List<PopupMenuEntry<String>>?
List of menu entry items of type T to appear in the popup menu.
inherited
onOffset() → Offset?
The offset is applied relative to the initial position
inherited
onOpened() → void
Called when the popup menu is shown.
inherited
onPadding() → EdgeInsetsGeometry?
In some cases, it's useful to be able to set the padding to zero.
inherited
onPosition() → PopupMenuPosition?
Whether the menu is positioned over or under the popup menu button
inherited
onSelected(String value) → void
Called when the user selects a value from the popup menu created by this button.
inherited
onShape() → ShapeBorder?
The shape used for the menu
inherited
onSplashRadius() → double?
The splash radius. If null, default splash radius of InkWell or IconButton is used.
inherited
onTooltip() → String?
Text that describes the action that will occur when the button is pressed.
inherited
setMenu() → void
Like setState() but for the popup menu
inherited
showButtonMenu() → void
Show the popup menu
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited